"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ComposerV2ReleaseResult = exports.ComposerV2PackageResponse = exports.ComposerV2Release = exports.PackageName = void 0;
const zod_1 = require("zod");
const composer_1 = require("../../versioning/composer");
exports.PackageName = zod_1.z
    .string()
    .refine((s) => s.split('/').length === 2, 'Invalid package name');
exports.ComposerV2Release = zod_1.z.object({
    version: zod_1.z.string(),
    homepage: zod_1.z.optional(zod_1.z.string().url()),
    source: zod_1.z.optional(zod_1.z.object({
        url: zod_1.z.string().url(),
    })),
    time: zod_1.z.string().datetime({ offset: true }),
});
exports.ComposerV2PackageResponse = zod_1.z.object({
    packages: zod_1.z.record(exports.PackageName, zod_1.z.array(exports.ComposerV2Release)),
});
exports.ComposerV2ReleaseResult = zod_1.z
    .array(exports.ComposerV2PackageResponse)
    .transform((responses) => {
    const releases = [];
    let maxVersion;
    let homepage = undefined;
    let sourceUrl = undefined;
    for (const response of responses) {
        for (const responsePackage of Object.values(response.packages)) {
            for (const composerV2Release of responsePackage) {
                const { version, time: releaseTimestamp } = composerV2Release;
                const dep = {
                    version: version.replace(/^v/, ''),
                    gitRef: version,
                    releaseTimestamp,
                };
                releases.push(dep);
                if (!composer_1.api.isValid(version)) {
                    continue;
                }
                if (!maxVersion || composer_1.api.isGreaterThan(version, maxVersion)) {
                    maxVersion = version;
                    homepage = composerV2Release.homepage;
                    sourceUrl = composerV2Release.source?.url;
                }
            }
        }
    }
    const result = { releases };
    if (homepage) {
        result.homepage = homepage;
    }
    if (sourceUrl) {
        result.sourceUrl = sourceUrl;
    }
    return result;
});
//# sourceMappingURL=schema.js.map